﻿using System;
using System.Collections.Generic;
using System.Data;
using System.Linq;
using System.Text;
using System.Threading.Tasks;

namespace Models.Game
{
    /// <summary>
    /// This class represents the best score of a player.
    /// </summary>
    public class BestScore
    {
        /// <summary>
        /// Number of games played by the user (on a specific map).
        /// </summary>
        private int _gamesPlayed;
        public int GamesPlayed
        {
            get => _gamesPlayed;
            private set
            {
                if (value >= 0)
                    _gamesPlayed = value;
                else _gamesPlayed = 0;
            }
        }
        
        /// <summary>
        /// Best score of the player (on a specific map).
        /// </summary>
        private int _score;
        public int Score
        {
            get => _score;
            private set
            {
                if (value >= 0)
                    _score = value;
                else _score = 0;
            }
        }

        /// <summary>
        /// Initialize a new instance of the BestScore class.
        /// </summary>
        /// <param name="gamesPlayed">Number of games played by the new user</param>
        /// <param name="score">Best score</param>
        public BestScore(int gamesPlayed, int score)
        {
            GamesPlayed = gamesPlayed;
            Score = score;
        }

        /// <summary>
        /// Increment the number of games played by the user.
        /// </summary>
        public void IncrGamesPlayed()
        {
            GamesPlayed += 1;
        }

        /// <summary>
        /// Update the best score of the player.
        /// </summary>
        /// <param name="newScore">New best score</param>
        public void UpdateScore(int newScore)
        {
            Score = newScore;
        }
    }
}
